---
title: Customizing Actions
page_title: Customizing Actions - Window - Kendo UI Wrappers for React
description: "Create custom actions in the Kendo UI Window wrapper for React."
slug: customizing_actions_window
position: 1
---

# Customizing Actions

The Window enables you to create and implement custom actions.

```jsx-preview
    class WindowContainer extends React.Component {
        constructor(props) {
            super(props);

            this.state = {
            isOpen: true,
            text: 'The button in the Window component is rendered!',
            windowProperties: {
            title: 'Window Demo',
            width: '400px',
            actions: [
                'Pin',
                'Minimize',
                'Maximize',
                'Close'
                ]}
        };

            this.changeInsideText = this.changeInsideText.bind(this);
            this.widgetRef = this.widgetRef.bind(this);
            this.openWindow = this.openWindow.bind(this);
            this.handleWindowClose = this.handleWindowClose.bind(this);
        }

        changeInsideText() {
            this.setState({text: 'You clicked the button!'});
        }

        widgetRef (Window) {
            this.window = Window;
        }

        openWindow() {
            this.window.open();
            this.setState({isOpen: true});
            this.setState({text: 'The button in the Window component is rendered!'});
        }

        handleWindowClose() {
            this.setState({isOpen: false});
        }

        render() {
            return (
                <div>
                    <Window {...this.state.windowProperties}
                            close={this.handleWindowClose}
                            widgetRef={this.widgetRef}>
                        <div id="inside-content">{this.state.text}</div>
                        <br />
                        <button className="k-button" onClick={this.changeInsideText}>Click this button </button>
                    </Window>
                    <button className="k-button"
                            onClick={this.openWindow}>
                        Open window
                    </button>
                </div>
            );
        }
    };

ReactDOM.render(
    <WindowContainer />,
    document.querySelector('my-app')
);
```

## Suggested Links

* [Kendo UI Window for jQuery](https://docs.telerik.com/kendo-ui/controls/layout/window/overview)
